* --------------------------------------------------------------------
* Project: The Effect of Information and Communication Technologies
*          on Urban Structure 
*          published in: Economic Policy, April 2008, pp. 201 - 242
* Authors: Yannis M. Ioannides, Henry G. Overman, 
*          Esteban Rossi-Hansberg, and Kurt Schmidheiny 
* Date:    December 7, 2007
* File:    moremeasures.do
* Title:   Estimate 
*          Gini coefficient for each country and year 
*          Herfindahl indices for each country and year 
*          Coefficient of variation for each country and year 
* --------------------------------------------------------------------

set more off
clear
use cities.dta, clear

sort countryid year

* total population in sample for country and year
by countryid year: egen pop_cities = sum(popcity)

* number of cities in sample for country and year
by countryid year: egen obs_cities = count(popcity)

* share of city population
generate sharecity_cities = popcity/pop_cities

* squared share of city population
generate sharecity_sq_cities = sharecity_cities^2	

* Herfindahl 
by countryid year: egen herf_cities = sum(sharecity_sq_cities) if obs_cities>1
* standardized Herfindahl 
generate herf_st_cities =  (herf_cities-(1/obs_cities))/(1-(1/obs_cities))

* Mean and variance of city sizes (as in the observed truncated sample!)
by countryid year: egen popmean_cities = mean(popcity) if obs_cities>1
by countryid year: egen popsd_cities = sd(popcity) if obs_cities>1
generate popvar_cities = popsd_cities^2
generate popcv_cities = popsd_cities/popmean_cities

* Mean and variance of standardized city sizes (as in the observed truncated sample!)
by countryid year: egen sharemean_cities = mean(sharecity_cities) if obs_cities>1
by countryid year: egen sharesd_cities = sd(sharecity_cities) if obs_cities>1
generate sharevar_cities = sharesd_cities^2

* Gini coefficient
by countryid year: egen rankcity = rank(popcity)
by countryid year: egen temp = sum(rankcity*(popcity-popmean_cities))
by countryid year: generate gini_cities = (2*temp)/(obs_cities^2*popmean_cities)

* consolidate results
drop if obs_ == .
collapse (mean) pop_ obs_ herf_* popmean_ popsd_ popvar_ popcv_ sharemean_ sharesd_ sharevar_ gini_, by(countrycode year)

label var pop_cities "total population in city sample"
label var obs_cities "number of cities in 1st stage regression"
label var herf_cities "Herfindahl index"
label var herf_st_cities "Herfindahl index, standardized"
label var popmean_cities "average population in city sample"
label var popsd_cities "std. deviation of population in city sample"
label var popvar_cities "variance population in city sample"
label var popcv_cities "coefficient of variation of population in city sample"
label var sharemean_cities "average standardized population in city sample"
label var sharesd_cities "std. deviation of standardized population in city sample"
label var sharevar_cities "variance of standardized population in city sample"
label var gini_cities "gini coefficient of population in city sample"

* create time variable with wave
sort countrycode year
by countrycode: egen wave_cities = seq()
lab var wave_cities "Wave of observation"

sort countrycode year

save moremeasures, replace
