* --------------------------------------------------------------------
* Project: The Effect of Information and Communication Technologies
*          on Urban Structure 
*          published in: Economic Policy, April 2008, pp. 201 - 242
* Authors: Yannis M. Ioannides, Henry G. Overman, 
*          Esteban Rossi-Hansberg, and Kurt Schmidheiny 
* Date:    December 7, 2007
* File:    table5.do
* Title:   Effect of phone lines using alternative measures of 
*          urban concentration
* --------------------------------------------------------------------

set more off
clear
use twostep.dta, clear

* --------------------------------------------------------------------
* restrict sample
* --------------------------------------------------------------------

* drop Germany
drop if countrycode == "DEU"

* restrict to Europe and Northern America
drop if ~(europe==1|northamerica==1)

* restrict to observations up to 2000
drop if year > 2000
drop if year < 1980

* --------------------------------------------------------------------
* data structure
* --------------------------------------------------------------------

* panel structure
tsset countryid time 

* --------------------------------------------------------------------
* create sample specific time averages
* --------------------------------------------------------------------

by countryid: egen govexp_avgpan = mean(govexp_mix)
lab var govexp_avgpan "=  mean(govexp_mix), years with city observations"

by countryid: egen obs_avgpan = mean(obs_cities_sc)
lab var obs_avgpan "=  mean(obs), years with city observations"

* --------------------------------------------------------------------
* estimation
* --------------------------------------------------------------------

* common sample for all estimations
quietly reg herf_cities lphones_sc invroaddens lnpop lngdppcppp trade nonagriva  govexp_avgpan gdpgrowth_sd lnarea obs_avgpan time
generate sample = e(sample)

* weights
generate weight = 1

* --------------------------------------------------------------------
* Gini
* --------------------------------------------------------------------

estimates clear

* column [1]: univariate, no fixed effects
reg gini_cities lphones_sc if sample [aw=weight]
estimates store m1

* column [2]: multivariate, no fixed effects
reg gini_cities lphones_sc invroaddens lnpop lngdppcppp trade nonagriva  govexp_avgpan gdpgrowth_sd lnarea obs_avgpan time if sample [aw=weight]
estimates store m2

* column [3]: univariate, fixed effects
xi: reg gini_cities lphones_sc i.countryid if sample [aw=weight]
estimates store m3

* column [4]: multivariate, fixed effects
xi: reg gini_cities lphones_sc invroaddens lnpop lngdppcppp trade nonagriva time i.countryid if sample [aw=weight]
estimates store m4

* column [5]: univariate, no fixed effects, iv
ivreg gini_cities (lphones_sc = monopub monopriv timeaftermonopub timeaftermonopriv eu nafta) if sample [aw=weight]
estimates store m5

* column [6]: multivariate, no fixed effects, iv
ivreg gini_cities (lphones_sc = monopub monopriv timeaftermonopub timeaftermonopriv eu nafta) invroaddens lnpop lngdppcppp trade nonagriva govexp_avgpan gdpgrowth_sd lnarea obs_avgpan time if sample [aw=weight]
estimates store m6

* column [7]: univariate, fixed effects, iv
xi: ivreg gini_cities (lphones_sc = monopub monopriv timeaftermonopub timeaftermonopriv eu nafta) i.countryid if sample [aw=weight]
estimates store m7

* column [8]: multivariate, fixed effects, iv
xi: ivreg gini_cities (lphones_sc = monopub monopriv timeaftermonopub timeaftermonopriv eu nafta) invroaddens lnpop lngdppcppp trade nonagriva time i.countryid if sample [aw=weight]
estimates store m8

* produce output table, tab-delimited text
set linesize 255
estout * using table5_gini.txt, stats(r2 N N_g) cells(b(star fmt(%9.3f)) se(fmt(%9.3f))) margin legend replace
estimates clear

* --------------------------------------------------------------------
* Herfindahl
* --------------------------------------------------------------------

estimates clear

* column [1]: univariate, no fixed effects
reg herf_cities lphones_sc if sample [aw=weight]
estimates store m1

* column [2]: multivariate, no fixed effects
reg herf_cities lphones_sc invroaddens lnpop lngdppcppp trade nonagriva  govexp_avgpan gdpgrowth_sd lnarea obs_avgpan time if sample [aw=weight]
estimates store m2

* column [3]: univariate, fixed effects
xi: reg herf_cities lphones_sc i.countryid if sample [aw=weight]
estimates store m3

* column [4]: multivariate, fixed effects
xi: reg herf_cities lphones_sc invroaddens lnpop lngdppcppp trade nonagriva time i.countryid if sample [aw=weight]
estimates store m4

* column [5]: univariate, no fixed effects, iv
ivreg herf_cities (lphones_sc = monopub monopriv timeaftermonopub timeaftermonopriv eu nafta) if sample [aw=weight]
estimates store m5

* column [6]: multivariate, no fixed effects, iv
ivreg herf_cities (lphones_sc = monopub monopriv timeaftermonopub timeaftermonopriv eu nafta) invroaddens lnpop lngdppcppp trade nonagriva govexp_avgpan gdpgrowth_sd lnarea obs_avgpan time if sample [aw=weight]
estimates store m6

* column [7]: univariate, fixed effects, iv
xi: ivreg herf_cities (lphones_sc = monopub monopriv timeaftermonopub timeaftermonopriv eu nafta) i.countryid if sample [aw=weight]
estimates store m7

* column [8]: multivariate, fixed effects, iv
xi: ivreg herf_cities (lphones_sc = monopub monopriv timeaftermonopub timeaftermonopriv eu nafta) invroaddens lnpop lngdppcppp trade nonagriva time i.countryid if sample [aw=weight]
estimates store m8

* produce output table, tab-delimited text
set linesize 255
estout * using table5_herf.txt, stats(r2 N N_g) cells(b(star fmt(%9.3f)) se(fmt(%9.3f))) margin legend replace
estimates clear

* --------------------------------------------------------------------
* Coefficient of variation
* --------------------------------------------------------------------

estimates clear

* column [1]: univariate, no fixed effects
reg popcv_cities lphones_sc if sample [aw=weight]
estimates store m1

* column [2]: multivariate, no fixed effects
reg popcv_cities lphones_sc invroaddens lnpop lngdppcppp trade nonagriva  govexp_avgpan gdpgrowth_sd lnarea obs_avgpan time if sample [aw=weight]
estimates store m2

* column [3]: univariate, fixed effects
xi: reg popcv_cities lphones_sc i.countryid if sample [aw=weight]
estimates store m3

* column [4]: multivariate, fixed effects
xi: reg popcv_cities lphones_sc invroaddens lnpop lngdppcppp trade nonagriva time i.countryid if sample [aw=weight]
estimates store m4

* column [5]: univariate, no fixed effects, iv
ivreg popcv_cities (lphones_sc = monopub monopriv timeaftermonopub timeaftermonopriv eu nafta) if sample [aw=weight]
estimates store m5

* column [6]: multivariate, no fixed effects, iv
ivreg popcv_cities (lphones_sc = monopub monopriv timeaftermonopub timeaftermonopriv eu nafta) invroaddens lnpop lngdppcppp trade nonagriva govexp_avgpan gdpgrowth_sd lnarea obs_avgpan time if sample [aw=weight]
estimates store m6

* column [7]: univariate, fixed effects, iv
xi: ivreg popcv_cities (lphones_sc = monopub monopriv timeaftermonopub timeaftermonopriv eu nafta) i.countryid if sample [aw=weight]
estimates store m7

* column [8]: multivariate, fixed effects, iv
xi: ivreg popcv_cities (lphones_sc = monopub monopriv timeaftermonopub timeaftermonopriv eu nafta) invroaddens lnpop lngdppcppp trade nonagriva time i.countryid if sample [aw=weight]
estimates store m8

* produce output table, tab-delimited text
set linesize 255
estout * using table5_cv.txt, stats(r2 N N_g) cells(b(star fmt(%9.3f)) se(fmt(%9.3f))) margin legend replace
estimates clear


