* ------------------------------------------------------------------------------
* Project: The Effect of Information and Communication Technologies
*          on Urban Structure 
*          published in: Economic Policy, April 2008, pp. 201 - 242
* Authors: Yannis M. Ioannides, Henry G. Overman, 
*          Esteban Rossi-Hansberg, and Kurt Schmidheiny 
* Date:    December 7, 2007
* File:    tableA2.do
* Title:   Internet users and the city size distribution (one-step estimation)
* ------------------------------------------------------------------------------

set more off
clear
use onestep.dta, clear

* ------------------------------------------------------------------------------
* restrict sample
* ------------------------------------------------------------------------------

* drop Germany
drop if countrycode == "DEU"

* restrict to Europe and Northern America
drop if ~(europe==1|northamerica==1)

* restrict to observations with phone data
drop if lnrank05 ==. | phones==.

* ------------------------------------------------------------------------------
* data structure
* ------------------------------------------------------------------------------

* set panel structure, 
* such that country-year specific constants are estimated
tsset countryyear cityid

* create country dummies, reference is USA
char countryid[omit] 198
xi i.countryid*lnpopcnorm

* ------------------------------------------------------------------------------
* estimation
* ------------------------------------------------------------------------------

estimates clear

* determine sample for regression with phone lines only
quietly xtreg lnrank05 lnpopcnorm _IcouXlnp_* lphon2lpopcn trade2lpopcn ird2lpopcn lpop2lpopcn time2lpopcn nonagr2lpopcn lgdpp2lpopcn govavgpan2lpopcn if year <= 2000, fe
generate sample1 = e(sample)

* allow all years for countries in above sample
bysort countryid: egen sample2 = max(sample1) 

* common sample for all estimations
quietly xtreg lnrank05 lnpopcnorm lphon2lpopcn linet2lpopcn ird2lpopcn lpop2lpopcn lgdpp2lpopcn trade2lpopcn nonagr2lpopcn govavgpan2lpopcn gdpsd2lpopcn larea2lpopcn obsavgpan2lpopcn time2lpopcn if sample2, fe
generate sample = e(sample)

* inet, OLS, no fixed effects
xtreg lnrank05 lnpopcnorm linet2lpopcn time2lpopcn if sample, fe 
estimates store m1
xtreg lnrank05 lnpopcnorm linet2lpopcn ird2lpopcn lpop2lpopcn lgdpp2lpopcn trade2lpopcn nonagr2lpopcn govavgpan2lpopcn gdpsd2lpopcn larea2lpopcn obsavgpan2lpopcn time2lpopcn if sample, fe 
estimates store m2
xtreg lnrank05 lnpopcnorm lphon2lpopcn linet2lpopcn time2lpopcn if sample, fe 
estimates store m3
xtreg lnrank05 lnpopcnorm lphon2lpopcn linet2lpopcn ird2lpopcn lpop2lpopcn lgdpp2lpopcn trade2lpopcn nonagr2lpopcn govavgpan2lpopcn gdpsd2lpopcn larea2lpopcn obsavgpan2lpopcn time2lpopcn if sample, fe 
estimates store m4

* produce output table, tab-delimited text
estout * using tableA2.txt, stats(r2 N N_g) cells(b(star fmt(%9.3f)) se(fmt(%9.3f))) margin legend replace

